@@ -87,7 +87,9 @@ RenameDialog::RenameDialog(QWidget *parent, const KFileItemList& items) :
     if (m_renameOneItem) {
         const QString fileName = items.first().url().prettyUrl();
         const QString extension = KMimeType::extractKnownExtension(fileName.toLower());
-        if (extension.length() > 0) {
+
+        // If the current item is a directory, select the whole file name.
+        if ((extension.length() > 0) && !items.first().isDir()) {
             // Don't select the extension
             selectionLength -= extension.length() + 1;
         }
@@ -160,11 +162,6 @@ void RenameDialog::slotTextChanged(const QString& newName)
 
 void RenameDialog::renameItems()
 {
-    // Currently the items are sorted by the selection order, resort
-    // them by the filename. This assures that the new sort order is similar to
-    // the current filename sort order.
-    qSort(m_items.begin(), m_items.end(), lessThan);
-
     // Iterate through all items and rename them...
     int index = m_spinBox->value();
     foreach (const KFileItem& item, m_items) {
